@@ -1,13 +1,13 @@
 require 'fog/aws/models/dns/zone'
 
 module Fog
-  module DNS
-    class AWS
+  module AWS
+    class DNS
       class Zones < Fog::Collection
         attribute :marker,    :aliases => 'Marker'
         attribute :max_items, :aliases => 'MaxItems'
 
-        model Fog::DNS::AWS::Zone
+        model Fog::AWS::DNS::Zone
 
         def all(options = {})
           options[:marker]   ||= marker unless marker.nil?
@@ -19,7 +19,7 @@ module Fog
         def get(zone_id)
           data = service.get_hosted_zone(zone_id).body
           new(data)
-        rescue Fog::DNS::AWS::NotFound
+        rescue Fog::AWS::DNS::NotFound
           nil
         end
       end
