@@ -7,6 +7,8 @@ module Fog
         attribute :owner_id,                :aliases => 'OwnerId'
         attribute :creation_token,          :aliases => 'CreationToken'
         attribute :performance_mode,        :aliases => 'PerformanceMode'
+        attribute :encrypted,               :aliases => 'Encrypted'
+        attribute :kms_key_id,              :aliases => 'KmsKeyId'
         attribute :creation_time,           :aliases => 'CreationTime'
         attribute :state,                   :aliases => 'LifeCycleState'
         attribute :name,                    :aliases => 'Name'
@@ -33,6 +35,8 @@ module Fog
         def save
           params = {}
           params.merge!(:performance_mode => self.performance_mode) if self.performance_mode
+          params.merge!(:encrypted        => self.encrypted)        if self.encrypted
+          params.merge!(:kms_key_id       => self.kms_key_id)       if self.kms_key_id
 
           merge_attributes(service.create_file_system(self.creation_token || Fog::Mock.random_hex(32), params).body)
         end
